==> IceWarpServer-9.1.0_RHEL5.tar.gz: html/webmail/client/inc/obj_attach_edit_select.js <==
_me = obj_attach_edit_select.prototype;
function obj_attach_edit_select(){};

/**
 * @date : 14.7.2006 10:26:59
 **/
_me.__constructor = function(){
	var me = this;
	this.__atts = {};

	this.attachments.__sortColumn = 'name';
	this.attachments._addColumns({name:{title:"DATAGRID_ITEMS_VIEW::EVNFILENAME",width:400,arg:{sort:'asc'}},size:{title:"DATAGRID_ITEMS_VIEW::EVNFILESIZE",width:100,arg:{sort:'asc'}}});

	this.attachments._ondblclick = function(e,elm,tr,arg,id){
		if (id) me._save({'atid':id});
	};

	this.attachments._oncontext = function(e,elm,etr,arg,sLineId,sColumn){
		//Klikly jsme na místo bez položek?
		if (!sLineId){
			return;
		}
		
		gui._create("cmenu","obj_context_attach",'','',me);
		var aMenu = [{"title":'ATTACHMENT::SAVE','arg':{'method':'save','atid':sLineId}},
			 {"title":'ATTACHMENT::SAVE_ALL','arg':{'method':'save_all','fullpath':me._gwPath},disabled:me.__disable_save_all},
			 {"title":'ATTACHMENT::REMOVE','arg':{'method':'delete_items','id':[sLineId]}}];
		gui.cmenu._fill(aMenu);
		gui.cmenu._place(e.clientX,e.clientY);
	};

    this._form;

	this.add_item._onclick = function() { gui._create('insert_item', 'frm_insert_item', '', '', [me, '__addItems']); };
	this.remove._onclick = function() { me.__deleteItems(me.attachments._value()); };
};

_me._onuploadstart = function(){
		this.__disable_save_all = true;
};

_me._save = function(arg) {
	switch (this.__atts[arg['atid']]['type']) {
		case 'item':
			// type 'item' can be only by item which hasn't been uploaded to the server yet. After upload
			// type 'item' is changed to 'attachment', so there is no need to check 'state' if it has
			// value "saved".
		case 'attachment':
		case 'file':
			var aUrl = {'sid': dataSet.get('main', ['sid']), 'class': this.__atts[arg['atid']]['type'], 'fullpath': this.__atts[arg['atid']]['fullpath']};
			downloadItem(buildURL(aUrl));
			break;
		case 'itemlink':
			var aValues;
			var sAccount;
			var sFolder;
			var sItem;
			var aPath = this.__splitFullPath(this.__atts[arg['atid']]['fullpath']);
			
			if (this.__atts[arg['atid']]['state'] == 'saved') {
				aValues = WMItems.list({"aid": aPath[0], "fid": aPath[1], "iid": aPath[2], "atid": arg['atid']});
				for (sAccount in aValues)
					for (sFolder in aValues[sAccount])
						for (sItem in aValues[sAccount][sFolder]);
						
				aValues = aValues[sAccount][sFolder][sItem];
				
			} else {
				aValues = WMItems.list({"aid": aPath[0], "fid": aPath[1], "iid": aPath[2]})[aPath[0]][aPath[1]][aPath[2]];
				sAccount = aPath[0];
				sFolder = aPath[1];
				sItem = aPath[2];
			}
			var sFolderType = dataSet.get("folders", [sAccount, sFolder, 'TYPE']);
			gui._create('gw', Mapping.getFormNameByGWType(sFolderType), '', '', sAccount, sFolder, sItem, aValues);
			break;
	}
};

_me._saveAll = function(arg) {
	var aUrl = {'sid':dataSet.get('main',['sid']),'class':'allattachments','fullpath':arg['fullpath']};
	downloadItem(buildURL(aUrl));
};

_me.__splitFullPath = function(sPath) {
	
	var aRet = [];
	var nIndex;

	if ((nIndex = sPath.indexOf('/')) >= 0) {
		aRet[0] = sPath.substring(0, nIndex);
		sPath = sPath.substring(nIndex+1);
	} else return [];
	
	if ((nIndex = sPath.lastIndexOf('/')) >= 0) {
	    aRet[2] = sPath.substring(nIndex+1);
		sPath = sPath.substring(0, nIndex);
	} else return [];
	
	aRet[1] = sPath;
		
	return aRet;
};

_me._addGuiElement = function(aArg, id) {

	if (!Is.Defined(aArg['type'])) aArg['type'] = 'file';

	this.__atts[aArg['id']] = aArg;

	switch (aArg['type']) {
		case 'file':
			this.__atts[aArg['id']]['fullpath'] = this._form['folder'].value+'/'+aArg['id'];
			break;

		case 'push_attachment':
			this.__atts[aArg['id']]['type'] = 'attachment';
			break;
		
		case 'attachment':
		    this.__atts[aArg['id']]['fullpath'] = this._gwPath+'/'+aArg['id'];
		    break;
		case 'itemlink':
		    if (aArg['state'] == 'saved') {
		    	this.__atts[aArg['id']]['fullpath'] = this._gwPath;
			}
	}
	
    this.__fillDataGrid();
};

_me.__fillDataGrid = function(){
	function parseSize(nSize){
		return Math.round(nSize*10/1024)/10+' kB';
	};

	var aData = [];
	for (var i in this.__atts)
		if (this.__atts[i]['state'] != 'to_delete')
			aData.push({id:i,data:{name:this.__atts[i].name,size:[parseSize(this.__atts[i].size || 0),this.__atts[i].Size || 0]},arg:{path:this.__atts[i].fullpath}});

	this.attachments._fill(aData);
};

_me.__addItems = function(aItems) {

	for (var i in aItems) {
	    
	    if (!this.__isIdInAtts(aItems[i]['id'])) {
	    	this._add({
				'name': aItems[i]['title'],
				'id': aItems[i]['id'],
				'size': aItems[i]['size'],
				'type': aItems[i]['type'] || (aItems[i]['embedded'] ? 'item' : 'itemlink'),
				'fullpath': aItems[i]['fullpath']
			});
		}
	}
};

_me.__isIdInAtts = function(id) {
    for (var i in this.__atts) if (this.__atts[i]['id'] == id && this.__atts[i]['type'] == 'item') return true;
    
    return false;
};

/*
 * Because of optimalizations removing gui elements is done only once in
 * __deleteItems at last line (this.__fillDataGrid()).
 */
_me._removeGuiElement = function(){}

_me.__deleteItems = function(aIDs) {
	for (var i in aIDs) {
		if (!this.__atts[aIDs[i]])
			continue;
		
		if (this.__atts[aIDs[i]]['state'] == 'saved' || this.__atts[aIDs[i]]['state'] == 'to_delete')
			this.__atts[aIDs[i]]['state'] = 'to_delete';
		else
			delete this.__atts[aIDs[i]];

		this._remove(aIDs[i]);
	}

	this.__fillDataGrid();
};

_me._value = function(v) {
	// Setting value is not supported
	if (Is.Defined(v)) {
		this._gwPath = v['path'];
		var aValues = v['values'];
		for (var i in aValues) this._add({'name': aValues[i]['values']['ATTDESC'], 'id': i, 'type': aValues[i]['values']['ATTTYPE'], 'size': aValues[i]['values']['ATTSIZE'], 'state': 'saved'});
	} else {
	    var aResult = [];
	    var aValue;
	    for (var i in this.__atts) {
			switch (this.__atts[i]['state']) {
			    case 'to_delete':
					aValue = {'uid': this.__atts[i]['id']};
					aResult.push(aValue);
					break;
			    case 'saved':
					break;
			    default:
					aValue = {'values': {'class': this.__atts[i]['type'] , 'description': this.__atts[i]['name'], 'fullpath': this.__atts[i]['fullpath']}};
					aResult.push(aValue);
			}
			
		}
		return aResult;
	}
};

==> IceWarpServer-9.4.1_RHEL5.tar.gz: html/webmail/client/inc/obj_attach_edit_select.js <==
_me = obj_attach_edit_select.prototype;
function obj_attach_edit_select(){};

/**
 * @date : 14.7.2006 10:26:59
 **/
_me.__constructor = function(){
	var me = this;
	this.__atts = {};

	this.attachments.__sortColumn = 'name';
	this.attachments._addColumns({name:{title:"DATAGRID_ITEMS_VIEW::EVNFILENAME",width:400,arg:{sort:'asc'}},size:{title:"DATAGRID_ITEMS_VIEW::EVNFILESIZE",width:100,arg:{sort:'asc'}}});

	this.attachments._ondblclick = function(e,elm,tr,arg,id){
		if (id) me._save({'atid':id});
	};

	this.attachments._oncontext = function(e,elm,etr,arg,sLineId,sColumn){
		//Klikly jsme na místo bez položek?
		if (!sLineId) return;

		gui._create("cmenu","obj_context",'','',me);
		var aMenu = [{"title":'ATTACHMENT::SAVE','arg':[me,'_save',[{'atid':sLineId}]]},
			 {"title":'ATTACHMENT::SAVE_ALL','arg':[me,'_saveAll',[{'fullpath':me._gwPath}]],disabled:me.__disable_save_all},
			 {"title":'ATTACHMENT::REMOVE','arg':[me,'__deleteItems',[[sLineId]]]}];

		gui.cmenu._fill(aMenu);
		gui.cmenu._place(e.clientX,e.clientY);
	};

    this._form;

	this.add_item._onclick = function() { gui._create('insert_item', 'frm_insert_item', '', '', [me, '__addItems']); };
	this.remove._onclick = function() { me.__deleteItems(me.attachments._value()); };
};

_me._onuploadstart = function(){
		this.__disable_save_all = true;
};

_me._save = function(arg) {
	switch (this.__atts[arg['atid']]['type']) {
		case 'item':
			// type 'item' can be only by item which hasn't been uploaded to the server yet. After upload
			// type 'item' is changed to 'attachment', so there is no need to check 'state' if it has
			// value "saved".
		case 'attachment':
		case 'file':
			var aUrl = {'sid': dataSet.get('main', ['sid']), 'class': this.__atts[arg['atid']]['type'], 'fullpath': this.__atts[arg['atid']]['fullpath']};
			downloadItem(buildURL(aUrl));
			break;
		case 'itemlink':
			var aValues;
			var sAccount;
			var sFolder;
			var sItem;
			var aPath = this.__splitFullPath(this.__atts[arg['atid']]['fullpath']);
			
			if (this.__atts[arg['atid']]['state'] == 'saved') {
				aValues = WMItems.list({"aid": aPath[0], "fid": aPath[1], "iid": aPath[2], "atid": arg['atid']});
				for (sAccount in aValues)
					for (sFolder in aValues[sAccount])
						for (sItem in aValues[sAccount][sFolder]);
						
				aValues = aValues[sAccount][sFolder][sItem];
				
			} else {
				aValues = WMItems.list({"aid": aPath[0], "fid": aPath[1], "iid": aPath[2]})[aPath[0]][aPath[1]][aPath[2]];
				sAccount = aPath[0];
				sFolder = aPath[1];
				sItem = aPath[2];
			}
			var sFolderType = dataSet.get("folders", [sAccount, sFolder, 'TYPE']);
			gui._create('gw', Mapping.getFormNameByGWType(sFolderType), '', '', sAccount, sFolder, sItem, aValues);
			break;
	}
};

_me._saveAll = function(arg) {
	var aUrl = {'sid':dataSet.get('main',['sid']),'class':'allattachments','fullpath':arg['fullpath']};
	downloadItem(buildURL(aUrl));
};

_me.__splitFullPath = function(sPath) {
	
	var aRet = [];
	var nIndex;

	if ((nIndex = sPath.indexOf('/')) >= 0) {
		aRet[0] = sPath.substring(0, nIndex);
		sPath = sPath.substring(nIndex+1);
	} else return [];
	
	if ((nIndex = sPath.lastIndexOf('/')) >= 0) {
	    aRet[2] = sPath.substring(nIndex+1);
		sPath = sPath.substring(0, nIndex);
	} else return [];
	
	aRet[1] = sPath;
		
	return aRet;
};

_me._addGuiElement = function(aArg, id) {

	if (!Is.Defined(aArg['type'])) aArg['type'] = 'file';

	this.__atts[aArg['id']] = aArg;

	switch (aArg['type']) {
		case 'file':
			this.__atts[aArg['id']]['fullpath'] = this._form['folder'].value+'/'+aArg['id'];
			break;

		case 'push_attachment':
			this.__atts[aArg['id']]['type'] = 'attachment';
			break;
		
		case 'attachment':
		    this.__atts[aArg['id']]['fullpath'] = this._gwPath+'/'+aArg['id'];
		    break;
		case 'itemlink':
		    if (aArg['state'] == 'saved') {
		    	this.__atts[aArg['id']]['fullpath'] = this._gwPath;
			}
	}
	
    this.__fillDataGrid();
};

_me.__fillDataGrid = function(){
	function parseSize(nSize){
		return Math.round(nSize*10/1024)/10+' kB';
	};

	var aData = [];
	for (var i in this.__atts)
		if (this.__atts[i]['state'] != 'to_delete')
			aData.push({id:i,data:{name:this.__atts[i].name,size:[parseSize(this.__atts[i].size || 0),this.__atts[i].Size || 0]},arg:{path:this.__atts[i].fullpath}});

	this.attachments._fill(aData);
};

_me.__addItems = function(aItems) {

	for (var i in aItems) {
	    
	    if (!this.__isIdInAtts(aItems[i]['id'])) {
	    	this._add({
				'name': aItems[i]['title'],
				'id': aItems[i]['id'],
				'size': aItems[i]['size'],
				'type': aItems[i]['type'] || (aItems[i]['embedded'] ? 'item' : 'itemlink'),
				'fullpath': aItems[i]['fullpath']
			});
		}
	}
};

_me.__isIdInAtts = function(id) {
    for (var i in this.__atts) if (this.__atts[i]['id'] == id && this.__atts[i]['type'] == 'item') return true;
    
    return false;
};

/*
 * Because of optimalizations removing gui elements is done only once in
 * __deleteItems at last line (this.__fillDataGrid()).
 */
_me._removeGuiElement = function(){}

_me.__deleteItems = function(aIDs) {

//inspect2(aIDs);return;
	for (var i in aIDs) {
		if (!this.__atts[aIDs[i]])
			continue;
		
		if (this.__atts[aIDs[i]]['state'] == 'saved' || this.__atts[aIDs[i]]['state'] == 'to_delete')
			this.__atts[aIDs[i]]['state'] = 'to_delete';
		else
			delete this.__atts[aIDs[i]];

		this._remove(aIDs[i]);
	}

	this.__fillDataGrid();
};

_me._value = function(v) {
	// Setting value is not supported
	if (Is.Defined(v)) {
		this._gwPath = v['path'];
		var aValues = v['values'];
		for (var i in aValues) this._add({'name': aValues[i]['values']['ATTDESC'], 'id': i, 'type': aValues[i]['values']['ATTTYPE'], 'size': aValues[i]['values']['ATTSIZE'], 'state': 'saved'});
	} else {
	    var aResult = [];
	    var aValue;
	    for (var i in this.__atts) {
			switch (this.__atts[i]['state']) {
			    case 'to_delete':
					aValue = {'uid': this.__atts[i]['id']};
					aResult.push(aValue);
					break;
			    case 'saved':
					break;
			    default:
					aValue = {'values': {'class': this.__atts[i]['type'] , 'description': this.__atts[i]['name'], 'fullpath': this.__atts[i]['fullpath']}};
					aResult.push(aValue);
			}
			
		}
		return aResult;
	}
};
